@@ -22,6 +22,7 @@ from .types.connection import (
     AwsAccessRole,
     AwsCrossAccountRole,
     AwsProperties,
+    AzureProperties,
     CloudResourceProperties,
     CloudSpannerProperties,
     CloudSqlCredential,
@@ -40,6 +41,7 @@ __all__ = (
     "AwsAccessRole",
     "AwsCrossAccountRole",
     "AwsProperties",
+    "AzureProperties",
     "CloudResourceProperties",
     "CloudSpannerProperties",
     "CloudSqlCredential",
